from os import path
from codecs import open
from setuptools import setup, find_packages

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='instabot',
    version='0.14.0',

    description='Instagram bot scripts for promotion and API python wrapper.',
    long_description=long_description,

    author='Daniil Okhlopkov, Evgeny Kemerov',
    author_email='danokhlopkov@gmail.com, eskemerov@gmail.com',
    license='Apache Software License 2.0',

    url='https://github.com/instagrambot/instabot',
    keywords=['instagram', 'bot', 'api', 'wrapper'],
    install_requires=[
        'tqdm>=4.30.0',
        'requests>=2.21.0',
        'requests-toolbelt>=0.8.0',
        'itsdangerous>=0.24',
        'click>=5.1',
        'schedule>=0.6.0',
        'pysocks>=1.6.8',
        'responses>=0.10.5',
        'future>=0.17.1',
        'six>=1.12.0',
        'huepy>=0.9.8.1',
    ],
    classifiers=[
        # How mature is this project? Common values are
        'Development Status :: 5 - Production/Stable',

        # Indicate who your project is intended for
        'Intended Audience :: Information Technology',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: Apache Software License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    packages=find_packages(),
)



import os
from io import open

from tqdm import tqdm


def upload_photo(self, photo, caption=None, upload_id=None, from_video=False):
    self.small_delay()
    if self.api.upload_photo(photo, caption, upload_id, from_video):
        self.logger.info("Photo '{}' is uploaded.".format(photo))
        return True
    self.logger.info("Photo '{}' is not uploaded.".format(photo))
    return False


def download_photo(self, media_id, folder='photos', filename=None, save_description=False):
    self.small_delay()
    if not os.path.exists(folder):
        os.makedirs(folder)
    if save_description:
        media = self.get_media_info(media_id)[0]
        caption = media['caption']['text'] if media['caption'] else ''
        username = media['user']['username']
        fname = os.path.join(folder, '{}_{}.txt'.format(username, media_id))
        with open(fname, encoding='utf8', mode='w') as f:
            f.write(caption)
    try:
        return self.api.download_photo(media_id, filename, False, folder)
    except Exception:
        self.logger.info("Media with `{}` is not downloaded.".format(media_id))
        return False


def download_photos(self, medias, folder, save_description=False):
    broken_items = []
    if not medias:
        self.logger.info("Nothing to downloads.")
        return broken_items
    self.logger.info("Going to download {} medias.".format(len(medias)))
    for media in tqdm(medias):
        if not self.download_photo(media, folder, save_description=save_description):
            self.error_delay()
            broken_items = medias[medias.index(media):]
    return broken_items
